@@ -28,9 +28,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <dirent.h>
-#include <dlfcn.h>
 #include <errno.h>
-#include <sys/time.h>
 #include <assert.h>
 
 #include <libprelude/prelude.h>
