@@ -36,9 +36,19 @@
 #include <signal.h>
 #include <dirent.h>
 #include <errno.h>
-#include <sys/time.h>
 #include <netinet/in.h> /* required by common.h */
 
+#if TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
+
 #include <libprelude/prelude.h>
 #include <libprelude/prelude-log.h>
 #include <libprelude/prelude-timer.h>
