@@ -111,6 +111,14 @@ static server_generic_t *add_server(void)
 }
 
 
+static void del_server(void)
+{
+        server_generic_destroy(config.server[config.nserver - 1]);
+        
+        config.nserver--;
+        config.server = _prelude_realloc(config.server, sizeof(*config.server) * config.nserver);
+}
+
 static int add_server_default(void)
 {
         char buf[128];
@@ -163,6 +171,7 @@ static int add_server_default(void)
                         if ( prelude_error_get_code(ret) == PRELUDE_ERROR_EADDRINUSE &&
                              prev_family != AF_UNSPEC && ai->ai_family != prev_family ) {
                                 ret = 0;
+                                del_server();
                                 continue;
                         }
                         
