@@ -29,9 +29,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <dirent.h>
-#include <dlfcn.h>
 #include <errno.h>
-#include <sys/time.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
