@@ -25,12 +25,21 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <sys/poll.h>
 #include <pthread.h>
 #include <assert.h>
 #include <errno.h>
 #include <signal.h>
-#include <sys/time.h>
+
+#if TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
 
 #include <libprelude/prelude-inttypes.h>
 #include <libprelude/prelude-list.h>
@@ -129,7 +138,7 @@ struct server_logic {
          */
         pthread_mutex_t mutex;
         prelude_list_t free_set_list;
-        prelude_list_t  used_set_list;
+        prelude_list_t used_set_list;
 
         volatile sig_atomic_t continue_processing;
 };
@@ -469,7 +478,6 @@ static void *child_reader(void *ptr)
                 }
                 
                 pthread_mutex_unlock(&set->parent->mutex);
-                
                 poll_fd_set(set);
         }
         
@@ -642,6 +650,22 @@ void server_logic_stop(server_logic_t *server)
 
 
 
+/**
+ * server_logic_destroy:
+ * @server: Pointer on a #server_logic_t object.
+ *
+ * Destroy the @server object.
+ *
+ * Warning: in the current state, server_logic_destroy() should only be 
+ * used if server_logic_process_requests() was not yet called.
+ */
+void server_logic_destroy(server_logic_t *server)
+{
+        pthread_mutex_destroy(&server->mutex);
+        free(server);
+}
+
+
 
 /**
  * server_logic_set_max_connection:
